@@ -2,6 +2,7 @@ use crate::dataset::Dataset;
 use crate::metadata::Metadata;
 use crate::raster::rasterband::ResampleAlg;
 use crate::raster::{ByteBuffer, ColorInterpretation, RasterCreationOption};
+use crate::vsi::unlink_mem_file;
 use crate::Driver;
 use gdal_sys::GDALDataType;
 use std::path::Path;
@@ -219,6 +220,19 @@ fn test_set_metadata_item() {
     assert_eq!(Some(value.to_owned()), result);
 }
 
+#[test]
+fn test_set_description() {
+    let driver = Driver::get("MEM").unwrap();
+    let dataset = driver.create("", 1, 1, 1).unwrap();
+    let mut band = dataset.rasterband(1).unwrap();
+
+    let description = "A merry and cheerful band description";
+    assert_eq!(band.description().unwrap(), "");
+
+    band.set_description(description).unwrap();
+    assert_eq!(band.description().unwrap(), description);
+}
+
 #[test]
 fn test_create() {
     let driver = Driver::get("MEM").unwrap();
@@ -290,11 +304,50 @@ fn test_create_with_band_type_with_options() {
 fn test_create_copy() {
     let driver = Driver::get("MEM").unwrap();
     let dataset = Dataset::open(fixture!("tinymarble.png")).unwrap();
-    let copy = dataset.create_copy(&driver, "").unwrap();
+    let copy = dataset.create_copy(&driver, "", &[]).unwrap();
     assert_eq!(copy.raster_size(), (100, 50));
     assert_eq!(copy.raster_count(), 3);
 }
 
+#[test]
+fn test_create_copy_with_options() {
+    let dataset = Dataset::open(fixture!("tinymarble.tif")).unwrap();
+
+    assert_eq!(
+        dataset.metadata_domain("IMAGE_STRUCTURE").unwrap(),
+        vec!["INTERLEAVE=PIXEL"]
+    );
+
+    let mem_file_path = "/vsimem/5128fad0-0a6b-4a9e-9899-ec78da7c6f04";
+
+    let copy = dataset
+        .create_copy(
+            &Driver::get("GTiff").unwrap(),
+            mem_file_path,
+            &[
+                RasterCreationOption {
+                    key: "INTERLEAVE",
+                    value: "BAND",
+                },
+                RasterCreationOption {
+                    key: "COMPRESS",
+                    value: "LZW",
+                },
+            ],
+        )
+        .unwrap();
+
+    assert_eq!(copy.raster_size(), (100, 50));
+    assert_eq!(copy.raster_count(), 3);
+
+    assert_eq!(
+        copy.metadata_domain("IMAGE_STRUCTURE").unwrap(),
+        vec!["COMPRESSION=LZW", "INTERLEAVE=BAND"]
+    );
+
+    unlink_mem_file(mem_file_path).unwrap();
+}
+
 #[test]
 #[allow(clippy::float_cmp)]
 fn test_geo_transform() {
@@ -592,3 +645,26 @@ fn test_color_interp_names() {
         ColorInterpretation::Undefined
     );
 }
+
+#[test]
+fn test_rasterize() {
+    let wkt = "POLYGON ((2 2, 2 4.25, 4.25 4.25, 4.25 2, 2 2))";
+    let poly = crate::vector::Geometry::from_wkt(wkt).unwrap();
+
+    let rows = 5;
+    let cols = 5;
+    let driver = Driver::get("MEM").unwrap();
+    let mut dataset = driver.create("", rows, cols, 1).unwrap();
+
+    let bands = [1];
+    let geometries = [poly];
+    let burn_values = [1.0];
+    super::rasterize(&mut dataset, &bands, &geometries, &burn_values, None).unwrap();
+
+    let rb = dataset.rasterband(1).unwrap();
+    let values = rb.read_as::<u8>((0, 0), (5, 5), (5, 5), None).unwrap();
+    assert_eq!(
+        values.data,
+        [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0,]
+    );
+}
